"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUTXOBalance = void 0;
const types_1 = require("@lifi/types");
const getUTXOAPIPublicClient_js_1 = require("./getUTXOAPIPublicClient.js");
const getUTXOPublicClient_js_1 = require("./getUTXOPublicClient.js");
const getUTXOBalance = async (walletAddress, tokens) => {
    if (tokens.length === 0) {
        return [];
    }
    const { chainId } = tokens[0];
    for (const token of tokens) {
        if (token.chainId !== chainId) {
            console.warn('Requested tokens have to be on the same chain.');
        }
    }
    const apiClient = await (0, getUTXOAPIPublicClient_js_1.getUTXOAPIPublicClient)(types_1.ChainId.BTC);
    const client = await (0, getUTXOPublicClient_js_1.getUTXOPublicClient)(types_1.ChainId.BTC);
    const [balance, blockCount] = await Promise.all([
        apiClient.getBalance({ address: walletAddress }),
        client.getBlockCount(),
    ]);
    return tokens.map((token) => ({
        ...token,
        amount: balance,
        blockNumber: BigInt(blockCount),
    }));
};
exports.getUTXOBalance = getUTXOBalance;
//# sourceMappingURL=getUTXOBalance.js.map